@@ -18,7 +18,7 @@ pred.rfsi <- function (model, # RFSI model
                        ...){ # ranger parameters + quantiles!!!
   
   # check the input
-  if (progress) print('Preparing data ...')
+  if (progress) message('Preparing data ...')
   if ((missing(data)) | missing(model) | missing(newdata)) {
     stop('The arguments model, data and newdata must not be empty!')
   }
@@ -82,7 +82,7 @@ pred.rfsi <- function (model, # RFSI model
   st.class <- c("sftime") #, "data.frame")
   sp.class <- c("sf", "SpatVector", "data.frame")
   if (soil3d) { # soil3D - data.frame
-    if (progress) print('Soil 3D process ...')
+    if (progress) message('Soil 3D process ...')
     data.cl <- "soil3D"
     if (!(any(class(data) %in% c(sp.class, "data.frame")))) {
       stop('The argument data must be or sf, SpatVector, or data.frame!')
@@ -92,18 +92,18 @@ pred.rfsi <- function (model, # RFSI model
     }
   } else { # not soil3D
     if (is.na(data.staid.x.y.z[4])) {
-      if (progress) print('Spatial process ...')
+      if (progress) message('Spatial process ...')
       data.cl <- "s"
       data.staid.x.y.z <- data.staid.x.y.z[1:3]
     } else { # space-time
-      if (progress) print('Space-time process ...')
+      if (progress) message('Space-time process ...')
       data.cl <- "st"
     }
   }
   
   sp.class <- c(sp.class, "SpatRaster")
   if (soil3d) { # soil3D - data.frame
-    if (progress) print('Soil 3D process ...')
+    if (progress) message('Soil 3D process ...')
     newdata.cl <- "soil3D"
     if (!(any(class(newdata) %in% c(sp.class, "data.frame")))) {
       stop('The argument newdata must be sf, SpatVector, SpatRaster, or data.frame!')
@@ -119,11 +119,11 @@ pred.rfsi <- function (model, # RFSI model
     }
   } else { # not soil3D
     if (is.null(z.value) & is.na(newdata.staid.x.y.z[4])) {
-      if (progress) print('Spatial process ...')
+      if (progress) message('Spatial process ...')
       newdata.cl <- "s"
       newdata.staid.x.y.z <- newdata.staid.x.y.z[1:3]
     } else { # space-time
-      if (progress) print('Space-time process ...')
+      if (progress) message('Space-time process ...')
       newdata.cl <- "st"
       if (!(any(class(newdata) %in% c(sp.class, "data.frame")))) {
         stop('The argument newdata must be sf, SpatVector, SpatRaster, or data.frame!')
@@ -165,18 +165,18 @@ pred.rfsi <- function (model, # RFSI model
   if (is.na(s.crs)) {
     warning('Data source CRS is NA! Using given coordinates for Euclidean distances calculation.')
   } else if (is.na(p.crs)) {
-    if (progress) print('Data projection CRS is NA Using source CRS for Euclidean distances calculation:')
-    if (progress) print(s.crs$input)
+    if (progress) warning('Data projection CRS is NA. Using source CRS for Euclidean distances calculation:')
+    if (progress) message(s.crs$input)
   } else if (identical(s.crs, p.crs)) {
-      if (progress) print('s.crs==p.crs')
+      if (progress) message('s.crs==p.crs')
   } else {
-    if (progress) print('Using data projection CRS for Euclidean distances calculation.')
+    if (progress) message('Using data projection CRS for Euclidean distances calculation.')
     prj_print <- try(paste('Do reprojection from: ', s.crs$input, ' to ', p.crs$input, sep=""), silent = TRUE)
     if(inherits(prj_print, "try-error")) {
       prj_print <- paste('Do reprojection from: ', s.crs@projargs, ' to ', p.crs@projargs, sep="")
     }
-    if (progress) print(prj_print)
-    # if (progress) print(paste('Do reprojection from: ', s.crs$input, ' to ', p.crs$input, sep=""))
+    if (progress) message(prj_print)
+    # if (progress) message(paste('Do reprojection from: ', s.crs$input, ' to ', p.crs$input, sep=""))
     # reproject data coordinates
     data.coord <- data.df[, data.staid.x.y.z[2:3]]
     data.coord <- st_as_sf(data.coord, coords = names(data.coord), crs = s.crs, agr = "constant")
@@ -191,21 +191,21 @@ pred.rfsi <- function (model, # RFSI model
     warning('Newdata source CRS is NA! Using given coordinates for Euclidean distances calculation.')
     final.crs <- NA
   } else if (is.na(p.crs)) {
-    if (progress) print('Newdata projection CRS is NA. Using source CRS for Euclidean distances calculation:')
-    if (progress) print(newdata.s.crs$input)
+    if (progress) warning('Newdata projection CRS is NA. Using source CRS for Euclidean distances calculation:')
+    if (progress) message(newdata.s.crs$input)
     final.crs <- newdata.s.crs
   } else if (identical(newdata.s.crs, p.crs)) {
-    if (progress) print('newdata.s.crs==p.crs')
+    if (progress) message('newdata.s.crs==p.crs')
     final.crs <- newdata.s.crs
   } else {
     old.newdata.x.y <- newdata.staid.x.y.z[2:3]
-    if (progress) print('Using newdata projection CRS for Euclidean distances calculation.')
+    if (progress) message('Using newdata projection CRS for Euclidean distances calculation.')
     prj_print <- try(paste('Do reprojection from: ', newdata.s.crs$input, ' to ', p.crs$input, sep=""), silent = TRUE)
     if(inherits(prj_print, "try-error")) {
       prj_print <- paste('Do reprojection from: ', newdata.s.crs@projargs, ' to ', p.crs@projargs, sep="")
     }
-    if (progress) print(prj_print)
-    # if (progress) print(paste('Do reprojection from: ', newdata.s.crs$input, ' to ', p.crs$input, sep=""))
+    if (progress) message(prj_print)
+    # if (progress) message(paste('Do reprojection from: ', newdata.s.crs$input, ' to ', p.crs$input, sep=""))
     # reproject data coordinates
     newdata.coord <- newdata.df[, newdata.staid.x.y.z[2:3]]
     newdata.coord <- st_as_sf(newdata.coord, coords = names(newdata.coord), crs = newdata.s.crs, agr = "constant")
@@ -234,8 +234,8 @@ pred.rfsi <- function (model, # RFSI model
       # if (!is.null(z.value)){
       rast.vect <- c()
       for (z.v in z.value) { # if length(z.value) > 1
-        if (progress) print(paste('Z: ', z.v, sep=""))
-        if (progress) print('Calculating distances to the nearest observations ...')
+        if (progress) message(paste('Z: ', z.v, sep=""))
+        if (progress) message('Calculating distances to the nearest observations ...')
         # day_df <- cbind(crds(newdata.df, na.rm=FALSE, df=T), z.v)
         day_df <- newdata.df[, c(newdata.x.y, newdata.3d.name)]
         nearest_obs <- near.obs.soil(
@@ -262,7 +262,7 @@ pred.rfsi <- function (model, # RFSI model
         newdata.df.z <- c(newdata.df, rast(nearest_obs_list))
         
         # prediction
-        if (progress) print('Doing RFSI predictions ...')
+        if (progress) message('Doing RFSI predictions ...')
         pf <- function(model, ...) {
           # library(ranger)
           predict(model, ..., num.threads = 1)$predictions
@@ -278,7 +278,7 @@ pred.rfsi <- function (model, # RFSI model
           cores = cpus,
           progress = "text",
           ...)
-        if (progress) print('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
+        if (progress) warning('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
         if (length(names(pred)) == 1) {
           names(pred) <- "pred"
         } # else { # else quantiles
@@ -316,7 +316,7 @@ pred.rfsi <- function (model, # RFSI model
       #   }
       #   newdata.df <- c(newdata.df, rast(nearest_obs_list))
       #   # prediction
-      #   if (progress) print('Doing RFSI predictions ...')
+      #   if (progress) message('Doing RFSI predictions ...')
       #   pf <- function(model, ...) {
       #     library(ranger)
       #     predict(model, ..., num.threads = 1)$predictions
@@ -332,7 +332,7 @@ pred.rfsi <- function (model, # RFSI model
       #     cores = cpus,
       #     progress = "text",
       #     ...)
-      #   if (progress) print('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
+      #   if (progress) message('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
       #   if (length(names(pred)) == 1) {
       #     names(pred) <- paste("pred_", z.v, sep="")
       #   } else {# else quantiles
@@ -348,8 +348,8 @@ pred.rfsi <- function (model, # RFSI model
       # if (!is.null(z.value)){
       rast.vect <- c()
       for (z.v in z.value) { # if length(z.value) > 1 ??? if there is no dynamic covariates
-        if (progress) print(paste('Z: ', z.v, sep=""))
-        if (progress) print('Calculating distances to the nearest observations ...')
+        if (progress) message(paste('Z: ', z.v, sep=""))
+        if (progress) message('Calculating distances to the nearest observations ...')
         dev_day_df.z <- dev_day_df[dev_day_df[, 3] == z.v, ]
         # day_df <- cbind(crds(newdata.df, na.rm=FALSE, df=T), z.v)
         day_df <- newdata.df[, newdata.x.y]
@@ -379,7 +379,7 @@ pred.rfsi <- function (model, # RFSI model
         names(newdata.z)
         
         # prediction
-        if (progress) print('Doing RFSI predictions ...')
+        if (progress) message('Doing RFSI predictions ...')
         pf <- function(model, ...) {
           # library(ranger)
           predict(model, ..., num.threads = 1)$predictions
@@ -395,7 +395,7 @@ pred.rfsi <- function (model, # RFSI model
           cores = cpus,
           progress = "text",
           ...)
-        if (progress) print('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
+        if (progress) warning('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
         if (length(names(pred)) == 1) {
           names(pred) <- "pred"
         } # else { # else quantiles
@@ -412,7 +412,7 @@ pred.rfsi <- function (model, # RFSI model
       # }
     } else { # if spatial
       # calculate obs and dist
-      if (progress) print('Calculating distances to the nearest observations ...')
+      if (progress) message('Calculating distances to the nearest observations ...')
       dev_day_df <- data.df[, c(x.y, obs.col.name)]
       # day_df <- crds(newdata.df, na.rm=FALSE, df=T)
       day_df <- newdata.df[, newdata.x.y]
@@ -443,7 +443,7 @@ pred.rfsi <- function (model, # RFSI model
       
       # calculate TPS - TO DO
       # if (use.tps) {
-      #   if (progress) print('Calculating TPS ...')
+      #   if (progress) message('Calculating TPS ...')
       #   m <- Tps(dev_day_df[, x.y], dev_day_df[, obs.col.name],# lon.lat = T,
       #            # lambda = tps.lambda) #, GCV= FALSE)
       #            df=tps.df)
@@ -452,7 +452,7 @@ pred.rfsi <- function (model, # RFSI model
       # }
       
       # prediction
-      if (progress) print('Doing RFSI predictions ...')
+      if (progress) message('Doing RFSI predictions ...')
       pf <- function(model, ...) {
         # library(ranger)
         predict(model, ..., num.threads = 1)$predictions
@@ -468,7 +468,7 @@ pred.rfsi <- function (model, # RFSI model
         cores = cpus,
         progress = "text",
         ...)
-      if (progress) print('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
+      if (progress) warning('Newdata is in SpatRaster format. output.format ignored, returning SpatRaster!')
       if (length(names(pred)) == 1) {
         names(pred) <- "pred"
       } # else quantiles
@@ -483,7 +483,7 @@ pred.rfsi <- function (model, # RFSI model
       daysNum = length(time)
       
       # calculate obs and dist
-      if (progress) print('Calculating distances to the nearest observations ...')
+      if (progress) message('Calculating distances to the nearest observations ...')
       registerDoParallel(cores=cpus)
       nearest_obs <- foreach (t = time, .export = c("near.obs")) %dopar% {
         
@@ -520,7 +520,7 @@ pred.rfsi <- function (model, # RFSI model
       
       # calculate TPS
       # if (use.tps) {
-      #   if (progress) print('Calculating TPS ...')
+      #   if (progress) message('Calculating TPS ...')
       #   registerDoParallel(cores=cpus)
       #   tps_fit <- foreach (t = time) %dopar% {
       #     dev_day_df <- data.df[data.df[, data.staid.x.y.z[4]]==t, c(x.y, obs.col.name)]
@@ -551,7 +551,7 @@ pred.rfsi <- function (model, # RFSI model
       # }
       
     } else if (data.cl == "soil3D") { # soil 3D
-      if (progress) print('Calculating distances to the nearest observations ...')
+      if (progress) message('Calculating distances to the nearest observations ...')
       dev_day_df <- data.df[, c(x.y, data.3d.name, obs.col.name)]
       day_df <- newdata.df[, c(newdata.x.y, newdata.3d.name)]
       nearest_obs <- near.obs.soil(
@@ -570,7 +570,7 @@ pred.rfsi <- function (model, # RFSI model
       newdata.df <- cbind(newdata.df, nearest_obs)
     } else { # if spatial
       # calculate obs and dist
-      if (progress) print('Calculating distances to the nearest observations ...')
+      if (progress) message('Calculating distances to the nearest observations ...')
       dev_day_df <- data.df[, c(x.y, obs.col.name)]
       day_df <- newdata.df[, c(newdata.x.y)]
       nearest_obs <- near.obs(
@@ -591,7 +591,7 @@ pred.rfsi <- function (model, # RFSI model
       
       # calculate TPS
       # if (use.tps) {
-      #   if (progress) print('Calculating TPS ...')
+      #   if (progress) message('Calculating TPS ...')
       #   m <- Tps(dev_day_df[, x.y], dev_day_df[, obs.col.name],# lon.lat = T,
       #            # lambda = tps.lambda) #, GCV= FALSE)
       #            df=tps.df)
@@ -607,7 +607,7 @@ pred.rfsi <- function (model, # RFSI model
     }
     
     # prediction
-    if (progress) print('Doing RFSI predictions ...')
+    if (progress) message('Doing RFSI predictions ...')
     pred <- predict(model, newdata.df, ...)$predictions
     if (exists("old.newdata.x.y")) {
       if (length(newdata.staid.x.y.z) == 4) {
@@ -629,16 +629,16 @@ pred.rfsi <- function (model, # RFSI model
     # sf$time <- Sys.time()
     sf$time <- as.POSIXct(sf$time)
     sftime <- st_sftime(sf)
-    if (progress) print("Done!")
+    if (progress) message("Done!")
     return(sftime)
   } else if (output.format == "sf") {
     sf <- st_as_sf(result, coords = names(result)[2:3], crs = final.crs, agr = "constant")
-    if (progress) print("Done!")
+    if (progress) message("Done!")
     return(sf)
   } else if (output.format == "SpatVector") {
     if (!is.na(final.crs)) {final.crs <- final.crs$wkt}
     sv <- terra::vect(result, geom = names(result)[2:3], crs = final.crs)
-    if (progress) print("Done!")
+    if (progress) message("Done!")
     return(sv)
   } else if (output.format == "SpatRaster") {
     if (!is.na(final.crs)) {final.crs <- final.crs$wkt}
@@ -661,10 +661,10 @@ pred.rfsi <- function (model, # RFSI model
         sr <- terra::rast(result[, c(2:3,4:length(result))], type="xyz", crs = final.crs)
       }
     }
-    if (progress) print("Done!")
+    if (progress) message("Done!")
     return(sr)
   } else { #  (output.format == "df")
-    if (progress) print("Done!")
+    if (progress) message("Done!")
     return(result)
   }
   
