@@ -4,7 +4,7 @@ tiling <- function(rast="", # path to grid file in SAGA format / raster formats
                    aspoints= NA, # "sf" # "sp"
                    asfiles=FALSE,                   
                    tilename="tile", # prexif to be given to tile names
-                   tiles_folder=paste(getwd(),'tiles',sep='/'), # resulting folder
+                   tiles_folder='tiles', # resulting folder
                    parallel.processing=FALSE,
                    cpus=6,
                    ...) # filetype="GTiff", overwrite = T, datatype = "INT2S"
